@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -718,6 +718,14 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
                "eur Iran",
                "",
             };
+        final String[] EMPTY_ZONE = new String[] {
+               "",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Easter = new String[] {
                "eur c\u02bchoa\u00f1v Enez Pask",
                "",
@@ -997,16 +1005,7 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             { "Asia/Tokyo", Japan },
             { "Europe/Bucharest", Europe_Eastern },
             { "Asia/Shanghai", China },
-            { "UTC",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
+            { "UTC", EMPTY_ZONE },
             { "Asia/Aden", Arabian },
             { "America/Cuiaba", Amazon },
             { "timezone.excity.Europe/San_Marino", "San Marino" },
@@ -1042,6 +1041,7 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             { "Asia/Yerevan", Armenia },
             { "Europe/Brussels", Europe_Central },
             { "timezone.excity.Atlantic/Reykjavik", "Reykjav\u00edk" },
+            { "JST", Japan },
             { "timezone.excity.Pacific/Fiji", "Fidji" },
             { "timezone.excity.Europe/Gibraltar", "Jibraltar" },
             { "Europe/Warsaw", Europe_Central },
@@ -1075,8 +1075,10 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             { "timezone.excity.America/El_Salvador", "Salvador" },
             { "Asia/Dubai", Gulf },
             { "Europe/Isle_of_Man", GMT },
+            { "BET", Brasilia },
             { "America/Araguaina", Brasilia },
             { "timezone.excity.Pacific/Easter", "Enez Pask" },
+            { "ACT", Australia_Central },
             { "timezone.excity.Pacific/Guam", "Guam" },
             { "Asia/Novosibirsk", Novosibirsk },
             { "timezone.excity.Europe/Vaduz", "Vaduz" },
@@ -1114,6 +1116,7 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             { "Africa/Asmera", Africa_Eastern },
             { "Europe/Busingen", Europe_Central },
             { "timezone.excity.Africa/Cairo", "Kaero" },
+            { "AET", Australia_Eastern },
             { "America/Argentina/Rio_Gallegos", Argentina },
             { "timezone.excity.America/Inuvik", "Inuvik" },
             { "Africa/Malabo", Africa_Western },
@@ -1138,16 +1141,6 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             { "Asia/Dili", East_Timor },
             { "timezone.excity.Australia/Perth", "Perth" },
             { "Africa/Bamako", GMT },
-            { "Europe/Saratov",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "timezone.excity.Arctic/Longyearbyen", "Longyearbyen" },
             { "Pacific/Wallis", Wallis },
             { "timezone.excity.America/Tegucigalpa", "Tegucigalpa" },
@@ -1197,16 +1190,6 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             { "Europe/Helsinki", Europe_Eastern },
             { "Asia/Beirut", Europe_Eastern },
             { "timezone.excity.Asia/Baghdad", "Baghdad" },
-            { "Pacific/Bougainville",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "timezone.excity.America/Montevideo", "Montevideo" },
             { "Africa/Sao_Tome", Africa_Western },
             { "America/Cayenne", French_Guiana },
@@ -1226,6 +1209,7 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             { "America/Yellowknife", America_Mountain },
             { "America/Juneau", Alaska },
             { "timezone.excity.Indian/Kerguelen", "Kergelenn" },
+            { "CNT", Newfoundland },
             { "America/Indiana/Vevay", America_Eastern },
             { "timezone.excity.America/Grenada", "Grenada" },
             { "timezone.excity.Europe/Volgograd", "Volgograd" },
@@ -1262,6 +1246,7 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             { "timezone.excity.America/Managua", "Managua" },
             { "Antarctica/Troll", GMT },
             { "Indian/Christmas", Christmas },
+            { "NET", Armenia },
             { "timezone.excity.America/Sao_Paulo", "S\u00e3o Paulo" },
             { "Pacific/Gambier", Gambier },
             { "America/Inuvik", America_Mountain },
@@ -1282,6 +1267,7 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             { "timezone.excity.America/Thule", "Q\u00e2n\u00e2q" },
             { "timezone.excity.Asia/Riyadh", "Riyadh" },
             { "America/Yakutat", Alaska },
+            { "America/Ciudad_Juarez", America_Mountain },
             { "Europe/Copenhagen", Europe_Central },
             { "timezone.excity.Africa/Bangui", "Bangui" },
             { "timezone.excity.Africa/Lusaka", "Lusaka" },
@@ -1320,6 +1306,7 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             { "Asia/Chongqing", China },
             { "Europe/Amsterdam", Europe_Central },
             { "timezone.excity.Asia/Saigon", "K\u00ear H\u00f4-Chi-Minh" },
+            { "PLT", Pakistan },
             { "Africa/Accra", GMT },
             { "timezone.excity.Africa/Niamey", "Niamey" },
             { "timezone.excity.Indian/Mayotte", "Mayotte" },
@@ -1342,6 +1329,7 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             { "America/Nassau", America_Eastern },
             { "timezone.excity.Africa/Conakry", "Conakry" },
             { "timezone.excity.Asia/Jakarta", "Jakarta" },
+            { "SST", Solomon },
             { "America/Jamaica", America_Eastern },
             { "Asia/Bishkek", Kyrgystan },
             { "Atlantic/Stanley", Falkland },
@@ -1351,6 +1339,7 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Calcutta", "Calcutta" },
             { "Indian/Mahe", Seychelles },
             { "Asia/Aqtobe", Kazakhstan_Western },
+            { "CTT", China },
             { "timezone.excity.Asia/Gaza", "Gaza" },
             { "Asia/Vladivostok", Vladivostok },
             { "Africa/Libreville", Africa_Western },
@@ -1363,6 +1352,7 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             { "Pacific/Marquesas", Marquesas },
             { "timezone.excity.Pacific/Rarotonga", "Rarotonga" },
             { "timezone.excity.Europe/Luxembourg", "Luksembourg" },
+            { "PNT", America_Mountain },
             { "America/Cayman", America_Eastern },
             { "Asia/Ulaanbaatar", Mongolia },
             { "Asia/Baghdad", Arabian },
@@ -1370,22 +1360,24 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Hong_Kong", "Hong Kong" },
             { "timezone.excity.America/Port-au-Prince", "Port-au-Prince" },
             { "Europe/San_Marino", Europe_Central },
+            { "BST", Bangladesh },
             { "timezone.excity.America/Mexico_City", "K\u00ear Vec\u02bchiko" },
             { "timezone.excity.Europe/Isle_of_Man", "Manav" },
             { "SystemV/YST9", Gambier },
             { "timezone.excity.Pacific/Nauru", "Nauru" },
             { "Africa/Douala", Africa_Western },
-            { "America/Ojinaga", America_Mountain },
             { "timezone.excity.Europe/Lisbon", "Lisboa" },
             { "timezone.excity.Pacific/Pago_Pago", "Pago Pago" },
             { "timezone.excity.Pacific/Gambier", "Gambier" },
             { "timezone.excity.America/Guyana", "Guyana" },
             { "Asia/Damascus", Europe_Eastern },
+            { "MIT", Apia },
             { "America/Argentina/San_Luis", Argentina_Western },
             { "timezone.excity.Europe/Paris", "Pariz" },
             { "America/Santiago", Chile },
             { "Asia/Baku", Azerbaijan },
             { "timezone.excity.Europe/Zagreb", "Zagreb" },
+            { "ART", Europe_Eastern },
             { "America/Argentina/Ushuaia", Argentina },
             { "Atlantic/Reykjavik", GMT },
             { "Africa/Brazzaville", Africa_Western },
@@ -1400,35 +1392,16 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             { "timezone.excity.Pacific/Chatham", "Chatham" },
             { "Africa/Dar_es_Salaam", Africa_Eastern },
             { "Atlantic/Madeira", Europe_Western },
-            { "Antarctica/Palmer",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "America/Thunder_Bay", America_Eastern },
             { "timezone.excity.Europe/Budapest", "Budapest" },
             { "timezone.excity.America/Port_of_Spain", "Port of Spain" },
             { "Africa/Addis_Ababa", Africa_Eastern },
+            { "AST", Alaska },
             { "Europe/Uzhgorod", Europe_Eastern },
             { "timezone.excity.Asia/Colombo", "Kolamba" },
             { "America/Indiana/Marengo", America_Eastern },
             { "timezone.excity.Pacific/Port_Moresby", "Port Moresby" },
             { "America/Creston", America_Mountain },
-            { "America/Punta_Arenas",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "timezone.excity.Europe/Helsinki", "Helsinki" },
             { "Europe/Andorra", Europe_Central },
             { "timezone.excity.Asia/Anadyr", "Anadyr\u02bc" },
@@ -1535,10 +1508,12 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Novosibirsk", "Novosibirsk" },
             { "Africa/Harare", Africa_Central },
             { "America/Nome", Alaska },
+            { "NST", New_Zealand },
             { "timezone.excity.Africa/Nairobi", "Nairobi" },
             { "Europe/Tallinn", Europe_Eastern },
             { "Africa/Khartoum", Africa_Central },
             { "Africa/Johannesburg", Africa_Southern },
+            { "EAT", Africa_Eastern },
             { "Africa/Bangui", Africa_Western },
             { "timezone.excity.Australia/Adelaide", "Adelaide" },
             { "timezone.excity.Asia/Singapore", "Singapour" },
@@ -1551,16 +1526,6 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             { "timezone.excity.America/Barbados", "Barbados" },
             { "timezone.excity.Asia/Nicosia", "Levkos\u00eda" },
             { "timezone.excity.Europe/Kiev", "Kiev" },
-            { "Europe/Astrakhan",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Africa/Juba", Africa_Eastern },
             { "America/Campo_Grande", Amazon },
             { "America/Belem", Brasilia },
@@ -1587,6 +1552,7 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             { "Pacific/Noumea", New_Caledonia },
             { "timezone.excity.Pacific/Norfolk", "Norfolk" },
             { "Asia/Tbilisi", Georgia },
+            { "ECT", Europe_Central },
             { "timezone.excity.Atlantic/Azores", "Azorez" },
             { "timezone.excity.Asia/Ashgabat", "Ashgabat" },
             { "timezone.excity.Australia/Melbourne", "Melbourne" },
@@ -1613,16 +1579,6 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             { "Asia/Khandyga", Yakutsk },
             { "Asia/Kuala_Lumpur", Malaysia },
             { "Asia/Thimphu", Bhutan },
-            { "Asia/Famagusta",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Asia/Rangoon", Myanmar },
             { "Europe/Bratislava", Europe_Central },
             { "timezone.excity.Indian/Christmas", "Christmas" },
@@ -1633,16 +1589,7 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             { "Pacific/Tongatapu", Tonga },
             { "SystemV/YST9YDT", Alaska },
             { "timezone.excity.Asia/Thimphu", "Thimphu" },
-            { "Europe/Ulyanovsk",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
+            { "CAT", Africa_Central },
             { "Arctic/Longyearbyen", Europe_Central },
             { "timezone.excity.Asia/Kuala_Lumpur", "Kuala Lumpur" },
             { "America/Fort_Nelson", America_Mountain },
@@ -1654,16 +1601,6 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             { "Asia/Ust-Nera", Vladivostok },
             { "timezone.excity.Africa/Gaborone", "Gaborone" },
             { "timezone.excity.Europe/Kaliningrad", "Kaliningrad" },
-            { "Asia/Srednekolymsk",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Asia/Anadyr", Anadyr },
             { "Australia/Melbourne", Australia_Eastern },
             { "Asia/Irkutsk", Irkutsk },
